@@ -79,6 +79,12 @@ static AppMgr::AppItem *parseDBus2AppItem(const ObjectInterfaceMap &source)
 
     // fallback to Name if GenericName is empty, only for X_Deepin_Vendor equals to "deepin".
     const auto deepinVendor = parseDBusField<QString>(appInfo, u8"X_Deepin_Vendor");
+    item->vendor = deepinVendor ? deepinVendor.value() : QString();
+    
+    // Get GenericName field
+    const auto genericNameMap = parseDBusField<QStringMap>(appInfo, u8"GenericName");
+    item->genericName = genericNameMap ? parseName(genericNameMap.value()) : QString();
+    
     item->displayName = getDisplayName(deepinVendor && deepinVendor.value() == QStringLiteral("deepin"),
                                        parseDBusField<QStringMap>(appInfo, u8"Name").value(),
                                        parseDBusField<QStringMap>(appInfo, u8"GenericName").value());
