@@ -116,17 +116,17 @@
 <context>
     <name>BottomBar</name>
     <message>
-        <location filename="../qml/windowed/BottomBar.qml" line="32"/>
+        <location filename="../qml/windowed/BottomBar.qml" line="33"/>
         <source>Power</source>
         <translation type="unfinished">གློག་ཁུངས།</translation>
     </message>
     <message>
-        <location filename="../qml/windowed/BottomBar.qml" line="56"/>
+        <location filename="../qml/windowed/BottomBar.qml" line="62"/>
         <source>Search</source>
         <translation type="unfinished">བཤེར་འཚོལ།</translation>
     </message>
     <message>
-        <location filename="../qml/windowed/BottomBar.qml" line="103"/>
+        <location filename="../qml/windowed/BottomBar.qml" line="109"/>
         <source>Full-screen Mode</source>
         <translation type="unfinished"></translation>
     </message>
@@ -147,7 +147,7 @@
 <context>
     <name>FrequentlyUsedView</name>
     <message>
-        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="35"/>
+        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="36"/>
         <source>Frequently Used</source>
         <translation type="unfinished"></translation>
     </message>
@@ -159,7 +159,7 @@
         <translation type="obsolete">བཤེར་འཚོལ།</translation>
     </message>
     <message>
-        <location filename="../qml/FullscreenFrame.qml" line="150"/>
+        <location filename="../qml/FullscreenFrame.qml" line="254"/>
         <source>Window Mode</source>
         <translation type="unfinished"></translation>
     </message>
@@ -167,12 +167,12 @@
 <context>
     <name>LauncherController</name>
     <message>
-        <location filename="../launchercontroller.cpp" line="19"/>
+        <location filename="../launchercontroller.cpp" line="21"/>
         <source>Show launcher (hidden by default)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../launchercontroller.cpp" line="20"/>
+        <location filename="../launchercontroller.cpp" line="22"/>
         <source>Toggle launcher visibility</source>
         <translation type="unfinished"></translation>
     </message>
@@ -206,7 +206,7 @@
     </message>
     <message>
         <location filename="../qml/Main.qml" line="32"/>
-        <source>Game</source>
+        <source>Games</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -235,17 +235,17 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qml/Main.qml" line="411"/>
-        <source>Are you sure you want to uninstall %1?</source>
+        <location filename="../qml/Main.qml" line="400"/>
+        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qml/Main.qml" line="423"/>
+        <location filename="../qml/Main.qml" line="412"/>
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qml/Main.qml" line="437"/>
+        <location filename="../qml/Main.qml" line="426"/>
         <source>Confirm</source>
         <translation type="unfinished"></translation>
     </message>
@@ -266,8 +266,8 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qml/FullscreenFrame.qml" line="566"/>
         <location filename="../qml/windowed/SearchResultView.qml" line="102"/>
+        <location filename="../qml/FullscreenFrame.qml" line="557"/>
         <source>No search results</source>
         <translation type="unfinished"></translation>
     </message>
@@ -295,27 +295,27 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qml/windowed/SideBar.qml" line="144"/>
+        <location filename="../qml/windowed/SideBar.qml" line="145"/>
         <source>Computer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qml/windowed/SideBar.qml" line="155"/>
+        <location filename="../qml/windowed/SideBar.qml" line="156"/>
         <source>Pictures</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qml/windowed/SideBar.qml" line="166"/>
+        <location filename="../qml/windowed/SideBar.qml" line="167"/>
         <source>Documents</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qml/windowed/SideBar.qml" line="177"/>
+        <location filename="../qml/windowed/SideBar.qml" line="178"/>
         <source>Desktop</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../qml/windowed/SideBar.qml" line="188"/>
+        <location filename="../qml/windowed/SideBar.qml" line="189"/>
         <source>Control Center</source>
         <translation type="unfinished"></translation>
     </message>
